Index: c/src/exec/score/cpu/i960/cpu.h
===================================================================
--- c/src/exec/score/cpu/i960/cpu.h	(revision c4b8161d88ed4f2a06e37b7473c44580467b64ab)
+++ c/src/exec/score/cpu/i960/cpu.h	(revision 75f09e52dea753e8ff655fcd16088135cd894136)
@@ -146,5 +146,5 @@
   boolean      do_zero_of_workspace;
   unsigned32   interrupt_stack_size;
-  unsigned32   extra_system_initialization_stack;
+  unsigned32   extra_mpci_receive_server_stack;
 #if defined(__i960CA__) || defined(__i960_CA__) || defined(__i960CA)
   i960ca_PRCB *Prcb;
@@ -174,11 +174,8 @@
 
 /*
- *  extra stack required by system initialization thread
- *
- *  NOTE: Make sure this stays positive ...
- */
-
-#define CPU_SYSTEM_INITIALIZATION_THREAD_EXTRA_STACK \
-   (CPU_STACK_MINIMUM_SIZE)
+ *  extra stack required by the MPCI receive server thread
+ */
+
+#define CPU_MPCI_RECEIVE_SERVER_EXTRA_STACK (CPU_STACK_MINIMUM_SIZE)
 
 /*
@@ -192,5 +189,5 @@
  *  Minimum size of a thread's stack.
  *
- *  NOTE:  See CPU_SYSTEM_INITIALIZATION_THREAD_EXTRA_STACK
+ *  NOTE:  See CPU_MPCI_RECEIVE_SERVER_EXTRA_STACK
  */
 
Index: c/src/exec/score/cpu/no_cpu/cpu.c
===================================================================
--- c/src/exec/score/cpu/no_cpu/cpu.c	(revision c4b8161d88ed4f2a06e37b7473c44580467b64ab)
+++ c/src/exec/score/cpu/no_cpu/cpu.c	(revision 75f09e52dea753e8ff655fcd16088135cd894136)
@@ -138,5 +138,5 @@
 /*PAGE
  *
- *  _CPU_Internal_threads_Idle_thread_body
+ *  _CPU_Thread_Idle_body
  *
  *  NOTES:
@@ -153,5 +153,5 @@
  */
 
-void _CPU_Internal_threads_Idle_thread_body( void )
+void _CPU_Thread_Idle_body( void )
 {
 
Index: c/src/exec/score/cpu/powerpc/cpu.h
===================================================================
--- c/src/exec/score/cpu/powerpc/cpu.h	(revision c4b8161d88ed4f2a06e37b7473c44580467b64ab)
+++ c/src/exec/score/cpu/powerpc/cpu.h	(revision 75f09e52dea753e8ff655fcd16088135cd894136)
@@ -235,7 +235,7 @@
  *  Does this port provide a CPU dependent IDLE task implementation?
  *
- *  If TRUE, then the routine _CPU_Internal_threads_Idle_thread_body
+ *  If TRUE, then the routine _CPU_Thread_Idle_body
  *  must be provided and is the default IDLE thread body instead of
- *  _Internal_threads_Idle_thread_body.
+ *  _CPU_Thread_Idle_body.
  *
  *  If FALSE, then use the generic IDLE thread body if the BSP does
@@ -442,5 +442,5 @@
   boolean      do_zero_of_workspace;
   unsigned32   interrupt_stack_size;
-  unsigned32   extra_system_initialization_stack;
+  unsigned32   extra_mpci_receive_server_stack;
   unsigned32   clicks_per_usec;	/* Timer clicks per microsecond */
   unsigned32   serial_per_sec;	/* Serial clocks per second */
@@ -531,9 +531,9 @@
 /*
  *  Amount of extra stack (above minimum stack size) required by
- *  system initialization thread.  Remember that in a multiprocessor
- *  system the system intialization thread becomes the MP server thread.
- */
-
-#define CPU_SYSTEM_INITIALIZATION_THREAD_EXTRA_STACK 0
+ *  MPCI receive server thread.  Remember that in a multiprocessor
+ *  system this thread must exist and be able to process all directives.
+ */
+
+#define CPU_MPCI_RECEIVE_SERVER_EXTRA_STACK 0
 
 /*
Index: c/src/exec/score/cpu/sparc/cpu.c
===================================================================
--- c/src/exec/score/cpu/sparc/cpu.c	(revision c4b8161d88ed4f2a06e37b7473c44580467b64ab)
+++ c/src/exec/score/cpu/sparc/cpu.c	(revision 75f09e52dea753e8ff655fcd16088135cd894136)
@@ -377,5 +377,5 @@
 /*PAGE
  *
- *  _CPU_Internal_threads_Idle_thread_body
+ *  _CPU_Thread_Idle_body
  *
  *  Some SPARC implementations have low power, sleep, or idle modes.  This
@@ -393,5 +393,5 @@
 #if defined(erc32)
 
-void _CPU_Internal_threads_Idle_thread_body( void )
+void _CPU_Thread_Idle_body( void )
 {
   while (1) {
Index: c/src/exec/score/cpu/unix/cpu.c
===================================================================
--- c/src/exec/score/cpu/unix/cpu.c	(revision c4b8161d88ed4f2a06e37b7473c44580467b64ab)
+++ c/src/exec/score/cpu/unix/cpu.c	(revision 75f09e52dea753e8ff655fcd16088135cd894136)
@@ -340,5 +340,5 @@
 /*PAGE
  *
- *  _CPU_Internal_threads_Idle_thread_body
+ *  _CPU_Thread_Idle_body
  *
  *  Stop until we get a signal which is the logically the same thing 
@@ -348,5 +348,5 @@
  */
 
-void _CPU_Internal_threads_Idle_thread_body( void )
+void _CPU_Thread_Idle_body( void )
 {
   while (1)
Index: cpukit/score/cpu/no_cpu/cpu.c
===================================================================
--- cpukit/score/cpu/no_cpu/cpu.c	(revision c4b8161d88ed4f2a06e37b7473c44580467b64ab)
+++ cpukit/score/cpu/no_cpu/cpu.c	(revision 75f09e52dea753e8ff655fcd16088135cd894136)
@@ -138,5 +138,5 @@
 /*PAGE
  *
- *  _CPU_Internal_threads_Idle_thread_body
+ *  _CPU_Thread_Idle_body
  *
  *  NOTES:
@@ -153,5 +153,5 @@
  */
 
-void _CPU_Internal_threads_Idle_thread_body( void )
+void _CPU_Thread_Idle_body( void )
 {
 
Index: cpukit/score/cpu/sparc/cpu.c
===================================================================
--- cpukit/score/cpu/sparc/cpu.c	(revision c4b8161d88ed4f2a06e37b7473c44580467b64ab)
+++ cpukit/score/cpu/sparc/cpu.c	(revision 75f09e52dea753e8ff655fcd16088135cd894136)
@@ -377,5 +377,5 @@
 /*PAGE
  *
- *  _CPU_Internal_threads_Idle_thread_body
+ *  _CPU_Thread_Idle_body
  *
  *  Some SPARC implementations have low power, sleep, or idle modes.  This
@@ -393,5 +393,5 @@
 #if defined(erc32)
 
-void _CPU_Internal_threads_Idle_thread_body( void )
+void _CPU_Thread_Idle_body( void )
 {
   while (1) {
Index: cpukit/score/cpu/unix/cpu.c
===================================================================
--- cpukit/score/cpu/unix/cpu.c	(revision c4b8161d88ed4f2a06e37b7473c44580467b64ab)
+++ cpukit/score/cpu/unix/cpu.c	(revision 75f09e52dea753e8ff655fcd16088135cd894136)
@@ -340,5 +340,5 @@
 /*PAGE
  *
- *  _CPU_Internal_threads_Idle_thread_body
+ *  _CPU_Thread_Idle_body
  *
  *  Stop until we get a signal which is the logically the same thing 
@@ -348,5 +348,5 @@
  */
 
-void _CPU_Internal_threads_Idle_thread_body( void )
+void _CPU_Thread_Idle_body( void )
 {
   while (1)

Index: c/src/exec/score/cpu/hppa1.1/cpu.h
===================================================================
--- c/src/exec/score/cpu/hppa1.1/cpu.h	(revision c4b8161d88ed4f2a06e37b7473c44580467b64ab)
+++ c/src/exec/score/cpu/hppa1.1/cpu.h	(revision 75f09e52dea753e8ff655fcd16088135cd894136)
@@ -224,5 +224,5 @@
 
   unsigned32   interrupt_stack_size;
-  unsigned32   extra_system_initialization_stack;
+  unsigned32   extra_mpci_receive_server_stack;
 
   /*
@@ -279,8 +279,8 @@
 
 /*
- *  extra stack required by system initialization thread
- */
-
-#define CPU_SYSTEM_INITIALIZATION_THREAD_EXTRA_STACK 0
+ *  extra stack required by the MPCI receive server thread
+ */
+
+#define CPU_MPCI_RECEIVE_SERVER_EXTRA_STACK 0
 
 /*
Index: c/src/exec/score/cpu/i386/cpu.h
===================================================================
--- c/src/exec/score/cpu/i386/cpu.h	(revision c4b8161d88ed4f2a06e37b7473c44580467b64ab)
+++ c/src/exec/score/cpu/i386/cpu.h	(revision 75f09e52dea753e8ff655fcd16088135cd894136)
@@ -104,5 +104,5 @@
   boolean      do_zero_of_workspace;
   unsigned32   interrupt_stack_size;
-  unsigned32   extra_system_initialization_stack;
+  unsigned32   extra_mpci_receive_server_stack;
 
   unsigned32   interrupt_table_segment;
@@ -135,8 +135,8 @@
 
 /*
- *  extra stack required by system initialization thread
- */
-
-#define CPU_SYSTEM_INITIALIZATION_THREAD_EXTRA_STACK 1024
+ *  extra stack required by the MPCI receive server thread
+ */
+
+#define CPU_MPCI_RECEIVE_SERVER_EXTRA_STACK 1024
 
 /*
Index: c/src/exec/score/cpu/m68k/cpu.h
===================================================================
--- c/src/exec/score/cpu/m68k/cpu.h	(revision c4b8161d88ed4f2a06e37b7473c44580467b64ab)
+++ c/src/exec/score/cpu/m68k/cpu.h	(revision 75f09e52dea753e8ff655fcd16088135cd894136)
@@ -139,5 +139,5 @@
   boolean      do_zero_of_workspace;
   unsigned32   interrupt_stack_size;
-  unsigned32   extra_system_initialization_stack;
+  unsigned32   extra_mpci_receive_server_stack;
   m68k_isr    *interrupt_vector_table;
 }   rtems_cpu_table;
@@ -167,8 +167,8 @@
 
 /*
- *  extra stack required by system initialization thread
- */
-
-#define CPU_SYSTEM_INITIALIZATION_THREAD_EXTRA_STACK 1024
+ *  extra stack required by the MPCI receive server thread
+ */
+
+#define CPU_MPCI_RECEIVE_SERVER_EXTRA_STACK 1024
 
 /*
Index: c/src/exec/score/cpu/no_cpu/cpu.h
===================================================================
--- c/src/exec/score/cpu/no_cpu/cpu.h	(revision c4b8161d88ed4f2a06e37b7473c44580467b64ab)
+++ c/src/exec/score/cpu/no_cpu/cpu.h	(revision 75f09e52dea753e8ff655fcd16088135cd894136)
@@ -208,7 +208,7 @@
  *  Does this port provide a CPU dependent IDLE task implementation?
  *
  *  If TRUE, then the routine _CPU_Internal_threads_Idle_thread_body
  *  must be provided and is the default IDLE thread body instead of
- *  _Internal_threads_Idle_thread_body.
+ *  _CPU_Thread_Idle_body.
  *
  *  If FALSE, then use the generic IDLE thread body if the BSP does
@@ -344,5 +344,5 @@
   boolean      do_zero_of_workspace;
   unsigned32   interrupt_stack_size;
-  unsigned32   extra_system_initialization_stack;
+  unsigned32   extra_mpci_receive_server_stack;
   unsigned32   some_other_cpu_dependent_info;
 }   rtems_cpu_table;
@@ -402,9 +402,9 @@
 /*
  *  Amount of extra stack (above minimum stack size) required by
- *  system initialization thread.  Remember that in a multiprocessor
- *  system the system intialization thread becomes the MP server thread.
- */
-
-#define CPU_SYSTEM_INITIALIZATION_THREAD_EXTRA_STACK 0
+ *  MPCI receive server thread.  Remember that in a multiprocessor
+ *  system this thread must exist and be able to process all directives.
+ */
+
+#define CPU_MPCI_RECEIVE_SERVER_EXTRA_STACK 0
 
 /*
@@ -760,5 +760,5 @@
 
 /*
- *  _CPU_Internal_threads_Idle_thread_body
+ *  _CPU_Thread_Idle_body
  *
  *  This routine is the CPU dependent IDLE thread body.
@@ -768,5 +768,5 @@
  */
 
-void _CPU_Internal_threads_Idle_thread_body( void );
+void _CPU_Thread_Idle_body( void );
 
 /*
@@ -208,7 +208,7 @@
  *  Does this port provide a CPU dependent IDLE task implementation?
  *
- *  If TRUE, then the routine _CPU_Internal_threads_Idle_thread_body
+ *  If TRUE, then the routine _CPU_Thread_Idle_body
  *  must be provided and is the default IDLE thread body instead of
Index: c/src/exec/score/cpu/sparc/cpu.h
===================================================================
--- c/src/exec/score/cpu/sparc/cpu.h	(revision c4b8161d88ed4f2a06e37b7473c44580467b64ab)
+++ c/src/exec/score/cpu/sparc/cpu.h	(revision 75f09e52dea753e8ff655fcd16088135cd894136)
@@ -146,7 +146,7 @@
  *  Does this port provide a CPU dependent IDLE task implementation?
  *
  *  If TRUE, then the routine _CPU_Internal_threads_Idle_thread_body
  *  must be provided and is the default IDLE thread body instead of
- *  _Internal_threads_Idle_thread_body.
+ *  _CPU_Thread_Idle_body.
  *
  *  If FALSE, then use the generic IDLE thread body if the BSP does
@@ -508,5 +508,5 @@
   boolean      do_zero_of_workspace;
   unsigned32   interrupt_stack_size;
-  unsigned32   extra_system_initialization_stack;
+  unsigned32   extra_mpci_receive_server_stack;
 }   rtems_cpu_table;
 
@@ -602,9 +602,9 @@
 /*
  *  Amount of extra stack (above minimum stack size) required by
- *  system initialization thread.  Remember that in a multiprocessor
- *  system the system intialization thread becomes the MP server thread.
- */
-
-#define CPU_SYSTEM_INITIALIZATION_THREAD_EXTRA_STACK 1024
+ *  MPCI receive server thread.  Remember that in a multiprocessor
+ *  system this thread must exist and be able to process all directives.
+ */
+
+#define CPU_MPCI_RECEIVE_SERVER_EXTRA_STACK 1024
 
 /*
@@ -899,5 +899,5 @@
  
 /*
- *  _CPU_Internal_threads_Idle_thread_body
+ *  _CPU_Thread_Idle_body
  *
  *  Some SPARC implementations have low power, sleep, or idle modes.  This
@@ -905,5 +905,5 @@
  */
  
-void _CPU_Internal_threads_Idle_thread_body( void );
+void _CPU_Thread_Idle_body( void );
  
 #endif /* CPU_PROVIDES_IDLE_THREAD_BODY */
@@ -146,7 +146,7 @@
  *  Does this port provide a CPU dependent IDLE task implementation?
  *
- *  If TRUE, then the routine _CPU_Internal_threads_Idle_thread_body
+ *  If TRUE, then the routine _CPU_Thread_Idle_body
  *  must be provided and is the default IDLE thread body instead of
Index: c/src/exec/score/cpu/unix/cpu.h
===================================================================
--- c/src/exec/score/cpu/unix/cpu.h	(revision c4b8161d88ed4f2a06e37b7473c44580467b64ab)
+++ c/src/exec/score/cpu/unix/cpu.h	(revision 75f09e52dea753e8ff655fcd16088135cd894136)
@@ -222,7 +222,7 @@
  *  Does this port provide a CPU dependent IDLE task implementation?
  *
  *  If TRUE, then the routine _CPU_Internal_threads_Idle_thread_body
  *  must be provided and is the default IDLE thread body instead of
- *  _Internal_threads_Idle_thread_body.
+ *  _CPU_Thread_Idle_body.
  *
  *  If FALSE, then use the generic IDLE thread body if the BSP does
@@ -472,5 +472,5 @@
   boolean      do_zero_of_workspace;
   unsigned32   interrupt_stack_size;
-  unsigned32   extra_system_initialization_stack;
+  unsigned32   extra_mpci_receive_server_stack;
 }   rtems_cpu_table;
 
@@ -543,9 +543,9 @@
 /*
  *  Amount of extra stack (above minimum stack size) required by
- *  system initialization thread.  Remember that in a multiprocessor
- *  system the system intialization thread becomes the MP server thread.
- */
-
-#define CPU_SYSTEM_INITIALIZATION_THREAD_EXTRA_STACK 0
+ *  MPCI receive server thread.  Remember that in a multiprocessor
+ *  system this thread must exist and be able to process all directives.
+ */
+
+#define CPU_MPCI_RECEIVE_SERVER_EXTRA_STACK 0
 
 /*
@@ -874,5 +874,5 @@
 
 /*
- *  _CPU_Internal_threads_Idle_thread_body
+ *  _CPU_Thread_Idle_body
  *
  *  This routine is the CPU dependent IDLE thread body.
@@ -882,5 +882,5 @@
  */
 
-void _CPU_Internal_threads_Idle_thread_body( void );
+void _CPU_Thread_Idle_body( void );
 
 /*
@@ -222,7 +222,7 @@
  *  Does this port provide a CPU dependent IDLE task implementation?
  *
- *  If TRUE, then the routine _CPU_Internal_threads_Idle_thread_body
+ *  If TRUE, then the routine _CPU_Thread_Idle_body
  *  must be provided and is the default IDLE thread body instead of